==> apache-ranger-2.0.0.tar.gz: apache-ranger-2.0.0/security-admin/src/test/java/org/apache/ranger/service/TestXAuditMapService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ranger.service;

import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.MethodSorters;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.apache.ranger.view.VXAuditMap;

@RunWith(MockitoJUnitRunner.class)
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class TestXAuditMapService {
	@InjectMocks
	XAuditMapService XAuditMapService;

	@Mock
	VXAuditMap vXAuditMap;

	@Test
	public void test1GetTransactionLog() {
		XAuditMapService.getTransactionLog(vXAuditMap, "delete");

	}

	@Test
	public void test2GetTransactionLog() {
		XAuditMapService.getTransactionLog(vXAuditMap, vXAuditMap, "delete");

	}

}

==> apache-ranger-2.5.0.tar.gz: apache-ranger-2.5.0/security-admin/src/test/java/org/apache/ranger/service/TestXAuditMapService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ranger.service;

import org.apache.ranger.biz.RangerBizUtil;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.MethodSorters;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.apache.ranger.view.VXAuditMap;

import static org.apache.ranger.service.RangerBaseModelService.OPERATION_DELETE_CONTEXT;

@RunWith(MockitoJUnitRunner.class)
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class TestXAuditMapService {
	@InjectMocks
	XAuditMapService XAuditMapService;

	@Mock
	VXAuditMap vXAuditMap;

	@Mock
	RangerBizUtil bizUtil;

	@Test
	public void test1GetTransactionLog() {
		XAuditMapService.createTransactionLog(vXAuditMap, null, OPERATION_DELETE_CONTEXT);
	}

	@Test
	public void test2GetTransactionLog() {
		XAuditMapService.createTransactionLog(vXAuditMap, vXAuditMap, OPERATION_DELETE_CONTEXT);
	}
}
